/* ver.B.b17.02(BLAZE) */


#include "version.h"


VERSION ap_version = {
	"AP.code",
	"cosmos",
	"(C) 2000-2007 Hirohisa Mori and GLOBALBASE Project",
	"ver.B.b17.02(BLAZE)",
	2008,3,16,
	0,
	"cosmos GLOBALBASE viewer ",
};

